==> ejc-mdm-impl-3.0.0-20231205.101655-153-sources.jar: com/ejianc/foundation/bulidMaterialMdm/bean/MadProjectEntity.java <==
package com.ejianc.foundation.bulidMaterialMdm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;

import java.util.Date;

/**
 * 筑材信息
 * 
 * @author generator
 * 
 */
 @TableName("projectmodel")
public class MadProjectEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="_master_data_id")
    private Long MasterDataId; // 主键ID
    @TableField(value="_last_update_time")
    private Date LastUpdateTime; // 最后一次修改时间
    @TableField(value="_data_type")
    private Integer DataType; // 数据状态（1：新增，2：修改，3：删除
    @TableField(value="orgId")
    private Long orgid; // 父组织id
    @TableField(value="orgName")
    private String orgname; // 父组织名称

    @TableField(value="projectDeptId")
    private Long projectdeptid; // 项目组织id
    @TableField(value="projectDeptName")
    private String projectdeptname; // 项目组织名称

    @TableField(value="code")
    private String code; // 组织编码
    @TableField(value="name")
    private String name; // 组织名称
    @TableField(value="orgType")
    private String orgtype; // 组织类型

    public String getOrgtype() {
        return orgtype;
}

    public void setOrgtype(String orgtype) {
        this.orgtype = orgtype;
    }

    public Long getMasterDataId() {
        return MasterDataId;
    }

    public void setMasterDataId(Long masterDataId) {
        MasterDataId = masterDataId;
    }

    public Date getLastUpdateTime() {
        return LastUpdateTime;
    }

    public void setLastUpdateTime(Date lastUpdateTime) {
        LastUpdateTime = lastUpdateTime;
    }

    public Integer getDataType() {
        return DataType;
    }

    public void setDataType(Integer dataType) {
        DataType = dataType;
    }


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public Long getProjectdeptid() {
        return projectdeptid;
    }

    public void setProjectdeptid(Long projectdeptid) {
        this.projectdeptid = projectdeptid;
    }

    public String getProjectdeptname() {
        return projectdeptname;
    }

    public void setProjectdeptname(String projectdeptname) {
        this.projectdeptname = projectdeptname;
    }
}

==> ejc-mdm-impl-3.0.0-20240701.011100-182-sources.jar: com/ejianc/foundation/bulidMaterialMdm/bean/MadProjectEntity.java <==
package com.ejianc.foundation.bulidMaterialMdm.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;

import java.util.Date;

/**
 * 筑材信息
 * 
 * @author generator
 * 
 */
 @TableName("projectmodel")
public class MadProjectEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="_master_data_id")
    private Long MasterDataId; // 主键ID
    @TableField(value="_last_update_time")
    private Date LastUpdateTime; // 最后一次修改时间
    @TableField(value="_data_type")
    private Integer DataType; // 数据状态（1：新增，2：修改，3：删除
    @TableField(value="orgId")
    private Long orgid; // 父组织id
    @TableField(value="orgName")
    private String orgname; // 父组织名称

    @TableField(value="projectDeptId")
    private Long projectdeptid; // 项目组织id
    @TableField(value="projectDeptName")
    private String projectdeptname; // 项目组织名称

    @TableField(value="code")
    private String code; // 组织编码
    @TableField(value="name")
    private String name; // 组织名称
    @TableField(value="orgType")
    private String orgtype; // 组织类型
    @TableField(value="project_department_id")
    private Long projectDepartmentId; // 组织类型


    public Long getProjectDepartmentId() {
        return projectDepartmentId;
    }

    public void setProjectDepartmentId(Long projectDepartmentId) {
        this.projectDepartmentId = projectDepartmentId;
    }

    public String getOrgtype() {
        return orgtype;
}

    public void setOrgtype(String orgtype) {
        this.orgtype = orgtype;
    }

    public Long getMasterDataId() {
        return MasterDataId;
    }

    public void setMasterDataId(Long masterDataId) {
        MasterDataId = masterDataId;
    }

    public Date getLastUpdateTime() {
        return LastUpdateTime;
    }

    public void setLastUpdateTime(Date lastUpdateTime) {
        LastUpdateTime = lastUpdateTime;
    }

    public Integer getDataType() {
        return DataType;
    }

    public void setDataType(Integer dataType) {
        DataType = dataType;
    }


    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getOrgid() {
        return orgid;
    }

    public void setOrgid(Long orgid) {
        this.orgid = orgid;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public Long getProjectdeptid() {
        return projectdeptid;
    }

    public void setProjectdeptid(Long projectdeptid) {
        this.projectdeptid = projectdeptid;
    }

    public String getProjectdeptname() {
        return projectdeptname;
    }

    public void setProjectdeptname(String projectdeptname) {
        this.projectdeptname = projectdeptname;
    }
}
